@@ -1,4 +1,5 @@
 """Code to handle the communication with Livisi Smart home controllers."""
+from __future__ import annotations
 from typing import Any
 import uuid
 
@@ -8,6 +9,7 @@ from .errors import (
     IncorrectIpAddressException,
     ShcUnreachableException,
     WrongCredentialException,
+    TokenExpiredException,
 )
 
 from .const import (
@@ -104,12 +106,12 @@ class AioLivisi:
         """Send a request to the Livisi Smart Home controller."""
         try:
             response = await self.__async_send_request(method, url, payload, headers)
+        except Exception:
+            response = await self.__async_send_request(method, url, payload, headers)
             if "errorcode" in response:
                 if response["errorcode"] == 2007:
-                    await self.async_set_token()
-            return response
-        except Exception:
-            return await self.__async_send_request(method, url, payload, headers)
+                    raise TokenExpiredException
+        return response
 
     async def __async_send_request(
         self, method, url: str, payload=None, headers=None
@@ -144,13 +146,13 @@ class AioLivisi:
                 device[LOCATION] = device[LOCATION].removeprefix("/location/")
         return devices
 
-    async def async_get_pss_state(self, capability) -> dict[str, Any]:
+    async def async_get_device_state(self, capability) -> dict[str, Any] | None:
         """Get the state of the PSS device."""
         url = f"{capability}/state"
         try:
             return await self.async_send_authorized_request("get", url)
-        except Exception as error:
-            return
+        except Exception:
+            return None
 
     async def async_pss_set_state(self, capability_id, is_on: bool) -> dict[str, Any]:
         """Set the PSS state."""
@@ -165,9 +167,27 @@ class AioLivisi:
             "post", "action", payload=set_state_payload
         )
 
+    async def async_vrcc_set_temperature(
+        self, capability_id, target_temperature: float, is_avatar: bool
+    ) -> dict[str, Any]:
+        """Set the Virtual Climate Control state."""
+        if is_avatar:
+            params = "setpointTemperature"
+        else:
+            params = "pointTemperature"
+        set_state_payload: dict[str, Any] = {
+            "id": uuid.uuid4().hex,
+            "type": "SetState",
+            "namespace": "core.RWE",
+            "target": capability_id,
+            "params": {params: {"type": "Constant", "value": target_temperature}},
+        }
+        return await self.async_send_authorized_request(
+            "post", "action", payload=set_state_payload
+        )
+
     async def async_get_all_rooms(self) -> dict[str, Any]:
         """Get all the rooms from LIVISI configuration."""
-
         return await self.async_send_authorized_request("get", "location")
 
     @property
